<?php

namespace Drupal\restuiextention\Normalizer;

use Drupal\serialization\Normalizer\ContentEntityNormalizer;

/**
 * Converts the Drupal entity object structures to a normalized array.
 */
class CustomTypedDataNormalizer extends ContentEntityNormalizer {

  /**
   * The interface or class that this Normalizer supports.
   *
   * Var string.
   */
  public function normalize($entity, $format = NULL, array $context = []) {
    $attributes = parent::normalize($entity, $format, $context);
    $final = [];
    foreach ($attributes as $key => $value) {
      $term_name = '';
      foreach ($value[0] as $k => $val) {
        if ($k != 'value') {
          $final[$key][$k] = $val;
          $tid = $value[0]['target_id'];
          if (isset($tid)) {
            $term = \Drupal::entityTypeManager()->getStorage('taxonomy_term')->load($tid);
            if (isset($term)) {
              $term_name = $term->name->value;
              $term_type = $term->getEntityTypeId();
              $final[$key]['target_id'] = $term_name;
              $final[$key]['target_type'] = $term_type;
            }
          }
        }
        else {
          $final[$key] = $val;
        }
      }
    }
	$final['status'] = '200';
    $final['message'] = 'Success';
    return $final;
  }

  /**
   * The interface or class that this Normalizer supports.
   *
   * Var string.
   */
  public function denormalize($data, $class, $format = NULL, array $context = []) {
    $collect = [];
    foreach ($data as $key => $value) {
      if (isset($value['target_id'])) {
        if ($value['target_type'] == 'taxonomy_term') {
          $term_name = $value['target_id'];
          $terms = \Drupal::entityTypeManager()
            ->getStorage('taxonomy_term')
            ->loadByProperties(['name' => $term_name]);
          $term = reset($terms);
          $collect[$key] = [
            '0' => ['target_id' => $term->id()],
          ];
        }
        else {
          $collect[$key] = [
            '0' => ['target_id' => $value['target_id']],
          ];
        }
      }
      else {
        $collect[$key] = [
          '0' => ['value' => $value],
        ];
      }
    }
    $return = parent::denormalize($collect, $class, $format, $context);
    return $return;
  }

}
